.. image:: https://img.shields.io/travis/figome/python-festung/master.svg?style=flat-square
  :target: https://travis-ci.org/figome/python-festung
.. image:: https://img.shields.io/pypi/v/festung.svg?style=flat-square
  :target: https://pypi.python.org/pypi/festung

Festung DBAPI for Python
========================

This library provides a `Database API v2.0`_ to Festung.

.. _Database API v2.0: https://www.python.org/dev/peps/pep-0249/
